/*==============================================================================


   Purpose:    determine processor number we are running on


   Author:     Rudolf Berrendorf
               Forschungszentrum Juelich GmbH
               Zentralinstitut fuer Angewandte Mathematik
               D-52425 Juelich
               Tel: ++49 2461 61-3218
               r.berrendorf@fz-juelich.de


   Date:       02.07.1999


   SUPPORT AND DISCLAIMER

   The software in this file (the "Software") is an unsupported product and is
   provided by Zentralinstitut fuer Angewandte Mathematik, Forschungszentrum
   Juelich GmbH (ZAM) "AS IS". We welcome comments, suggestions, and problem
   reports and ask that you mail those to kfazam@kfa-juelich.de; however, we
   make no promises to respond to any item.

   ZAM makes no warrranties or representations, expressed or implied, including,
   but not limited to, implied warranties of merchantability and fitness for a
   particular purpose, as to any element of the Software or any support
   provided in connection with the Software. In no event shall ZAM be
   responsible for any damages, including but not limited to consequential
   damages, arising from or relating to any use of the Software or related
   support.


   COPYRIGHT

   (c) COPYRIGHT 1999
   Zentralinstitut fuer Angewandte Mathematik, Forschungszentrum Juelich GmbH

   The Software is copyrighted. For research purposes, you can use it for free.
   If you plan to use it commercially, please contact zam@fz-juelich.de.


==============================================================================*/

#include "processor_number.h"

#if defined(ALPHA_CRAY)
#include <unistd.h>

#elif defined(ALPHA_DEC)
#include <sys/processor.h>
#include <sys/sysinfo.h>

#elif defined(MIPS)

#elif defined(SPARC)
#include <sys/types.h>
#include <sys/processor.h>
#include <sys/procset.h>

#elif defined(POWERPC)

#elif defined(PENTIUM_LINUX)
#include <linux/smp.h>

#else
#error "unsupported system"
#endif


/*============================================================================*/
/* determine processor number we are running on (-1 if not available)         */


int PCL_processor_number(void)

{
#if defined(ALPHA_CRAY)
  return sysconf(_SC_CRAY_PPE);

#elif defined(ALPHA_DEC)
  int proc;

  getsysinfo(GSI_CURRENT_CPU,&proc,sizeof(proc),NULL,NULL,NULL);
  return proc;

#elif defined(MIPS)
  /* ??? */
  return -1;

#elif defined(SPARC)
  int proc;

  /*??? works only if process is bound to processor */
  processor_bind(P_LWPID, P_MYID, PBIND_QUERY, &proc);
  return proc;

#elif defined(POWERPC)
  /* ??? */
  return -1;

#elif defined(PENTIUM_LINUX)
  return smp_processor_id();

#elif defined(PENTIUM_NT)
  return -1;
  /* ??? not done yet */

#else
#error "unsupported system"
#endif
}


/*============================================================================*
 *                             that's all folks                               *
 *============================================================================*/
